#! /usr/bin/env node
const pkg			= require('./package');
const program	= require('commander');
const ug			= require('./modules/ug');

// Set up commander
program
	.version(pkg.version)
	.usage('[options] <search terms>')
	.option('-a, --artist <string>', 'Limit search results by artist')
	.option('-t, --type <string>', 'Limit search results by type (chords, tabs, bass, ukelele)', /^(tabs|chords|bass|ukulele)$/i)
	.parse(process.argv);

// Show help if no search terms or artist
if (program.args.length < 1 && !program.artist) {
	program.outputHelp();
	process.exit(1);
}

// Replace pluses with spaces for the artist name
if (program.artist && program.artist.indexOf('+') !== -1) program.artist = program.artist.replace(/\+/g, ' ');

// If their type isn't valid, tell them and exit
if (program.type && typeof program.type !== 'string') {
	console.log('Invalid type. Valid types are "tabs", "chords", "bass", or "ukulele".');
	process.exit(1);
}

// Change type from string to number if it exists
if (program.type) {
	program.type = program.type.toLowerCase();
	switch (program.type) {
		case 'tabs':
			program.type = 200;
			break;
		case 'chords':
			program.type = 300;
			break;
		case 'bass':
			program.type = 400;
			break;
		case 'ukulele':
			program.type = 800;
			break;
		default:
			program.type = false;
			break;
	}
};

let args = {
	termsArr: program.args,
	artist: program.artist || null,
	type: program.type || null
};

ug.search(args, (err, songs) => {
	if (err) console.error(err);
	let bestSong = { rating: -1, votes: -1 };
	songs.forEach((song, index) => {
		if (!song.rating) song.rating = 0;
		if (!song.votes) song.votes = 0;
		if (!song.marketing_type && ug.bogusTypes.indexOf(song.type) === -1) {
			if (song.rating > bestSong.rating) {
				bestSong = song;
			} else if (song.rating === bestSong.rating && song.votes > bestSong.votes) {
				bestSong = song;
			}
		}
		if (index === songs.length - 1) {
			ug.getTab(bestSong.tab_url, (err, tab) => {
				if (err || !tab) {
					console.log(err ? 'Oops, something broke!' : 'No tab found!');
				} else {
					console.log('\'' + bestSong.song_name + '\' by ' + bestSong.artist_name);
					console.log(tab.replace(/\[\/?ch\]/g, ''));
				}
			});
		}
	});
});
